@@ -13,10 +13,14 @@ findRoots <-
         ##     }
         ## }
 
-        optim.object <- do.call(nleqslv, c(list(x = beta.init, fn = eq.func,
-                                                    jac = d.eq.func, arg.list = arg.list), list(...)))
+        optim.object <- do.call(nleqslv, c(list(x = beta.init,
+                                                fn = eq.func,
+                                                jac = d.eq.func,
+                                                arg.list = arg.list),
+                                           list(...)))
 
         beta.hat <- optim.object$x
+        
         if (optim.object$termcd > 2) {
             warning(paste("\nnleqslv: ", optim.object$message))
         }
